This directory contains examples, categorized as follows:

- **[Notebooks](notebooks/)**: These are examples in the form of Jupyter notebooks. They demonstrate the usage of EvoTorch on various problems, and can serve as tutorials to the interested reader.
- **[Scripts](scripts/)**: These are scripts which can be used as command line utilities for training, saving, and visualizing reinforcement learning policies.
